<input type="text" name="{{ name }}" {% if value %}value="rgb({{ value }})"{% endif %} id="{{ attrs.id }}"
       class="colorfield_field jscolor {% if not is_required %}{required:false}{% endif %}"/>
